
import Link from 'next/link'
import React, { useEffect, useState, useRef } from 'react'

import '../../../public/assets/theme4/libs/tiny-slider/tiny-slider.css';
import './assets4/css/bootstrap.min.css';
import './assets4/css/icons.min.css';
import '../../../public/assets/theme4/libs/@iconscout/unicons/css/line.css';
import './assets4/css/style.min.css';


import Script from 'next/script';
import Image from 'next/image';

const Home = ({ apiResData }) => {

  const [loading, setLoading] = useState(true);
  const [showMenu, setShowMenu] = useState(false);
  const [activeTab, setActiveTab] = useState('1');
  const [activePlan, setActivePlan] = useState('1');

  useEffect(() => {
    const script = document.createElement('script');
    script.src = '/assets/theme4/js/app.js';
    script.async = true;
    document.body.appendChild(script);

    return () => {
      document.body.removeChild(script);
    };
  }, []);


  useEffect(() => {
    if (apiResData) {
      setLoading(false);
    }
  }, [apiResData]);

  const primaryColor = apiResData?.web_primary_color
  const secondaryColor = apiResData?.web_secondary_color

  useEffect(() => {
    if (!loading) {
      document.documentElement.style.setProperty('--white', primaryColor);
      document.documentElement.style.setProperty('--theme', secondaryColor);
    }
  }, [loading, primaryColor, secondaryColor]);



  const gradientStyle = {
    background: 'linear-gradient(90deg, rgba(239,141,0,1) 0%, rgba(0,83,136,1) 100%)',
    padding: '50px',
    animation: 'gradient 15s ease infinite',
    backgroundSize: '200% 200%',
  };

  const h3Style = {
    color: '#fff',
  };

  const gradientKeyframes = `
    @keyframes gradient {
      0% {
        background-position: 0% 50%;
      }
      50% {
        background-position: 100% 50%;
      }
      100% {
        background-position: 0% 50%;
      }
    }
  `;

  if (loading) {
    return <div></div>;
  }

  return (

    <>
      <style jsx global>{`
        :root {
         --white: ${primaryColor};
         --theme: ${secondaryColor};
        }
      `}</style>
      <div>

        <header id="topnav" className="defaultscroll sticky" style={{ padding: '0px 0px' }}>
          <div className="container">
            {/* Logo container*/}
            <a className="logo" href="#">
              <img src={apiResData?.logo} style={{ width: 180, height: 54 }} className="logo-light-mode" />
              <img src={apiResData?.logo} style={{ width: 180, height: 54 }} className="logo-dark-mode" />
            </a>
            {/* End Logo container*/}
            <div className="menu-extras">
              <div className="menu-item">
                {/* Mobile menu toggle*/}
                <a className="navbar-toggle" id="isToggle" onClick={() => setShowMenu(!showMenu)}>
                  <div className="lines">
                    <span />
                    <span />
                    <span />
                  </div>
                </a>
                {/* End mobile menu toggle*/}
              </div>
            </div>
            <div id="navigation" style={{ display: `${showMenu ? 'block' : 'none'}` }}>
              {/* Navigation Menu*/}
              <ul className="navigation-menu">
                <li><a href="/" className="sub-menu-item">Home</a></li>
                <li className="has-submenu parent-parent-menu-item">
                  <a href="#about">About Us</a>
                </li>
                <li className="has-submenu parent-parent-menu-item">
                  <a href="#services">Services</a>
                </li>
                <li className="has-submenu parent-parent-menu-item">
                  <a href="#plan">Plan</a>
                </li>
                <li className="has-submenu parent-menu-item">
                  <a href="#contact">Contact Us </a><span className="submenu-arrow" />
                </li>
                <div className="buy-button">
                </div>
                <div className="buy-button">
                  <a href="/login" target="_blank">
                    <div className="btn btn-primary">Login</div>
                  </a>
                </div>
              </ul>
            </div>
          </div>
        </header>
        <form method="post" action="./" id="form1">
          <input type="hidden" name="__VIEWSTATE" id="__VIEWSTATE" defaultValue="/wEPDwUKMTY1NDU2MTA1MmRkYUlqOx4EsepIsv3MiK9Nd/4h0MMqFSjM/Lw57Vw8/VM=" />
          <input type="hidden" name="__VIEWSTATEGENERATOR" id="__VIEWSTATEGENERATOR" defaultValue="CA0B0334" />
          <div>
            <section className="bg-half-170 pb-0 bg-light d-table w-100 overflow-hidden">
              <div className="container">
                <div className="row align-items-center mt-5 mt-sm-0">
                  <div className="col-md-6">
                    <div className="title-heading text-center text-md-start">
                      <h4 className="heading mb-3 mt-2">Best Aeps Service,<br /> Provider In India.</h4>
                      <p className="text-muted mb-0 para-dark para-desc mx-auto ms-md-auto">Aeps Service Is The Best AEPS Service Provider Company In India, Delivering Over 15 Services With Fast Move To Bank Transfers, Rapid Customer Support, And Many Services. And Aeps Service Is At Top In Aeps Service Provider Company List..</p>
                      <div className="mt-4">
                        <a href="/login" className="btn btn-primary" style={{ margin: '10px 0px' }}>Login</a>
                      </div>
                    </div>
                  </div>
                  <div className="col-md-6 mt-4 pt-2 mt-sm-0 pt-sm-0">
                    <div className="freelance-hero position-relative">
                      <div className="bg-shape position-relative">
                        <img src="/assets/theme4/images/homebanner.webp" className="mx-auto d-block img-fluid" alt />
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </section>


            <div style={gradientStyle}>
              <center>
                <h3 style={h3Style}>
                  Become a Retailer and Earn upto Rs.1 Lakh per month.
                </h3>
                <div>
                  <a href="/login">
                    <div className="btn btn-primary">Sign Up</div>
                  </a>
                </div>
              </center>
            </div>

            {/* <style jsx>{gradientKeyframes}</style> */}



            <section className="section" id="about">
              <div className="container">
                <div className="row align-items-center">
                  <div className="col-lg-5 col-12 order-1 order-lg-2">
                    <div className="section-title text-center text-lg-start mb-4 mb-lg-0 pb-2 pb-lg-0">
                      <span className="badge rounded-pill bg-soft-primary">10-year-old company </span>
                      <h4 className="title mt-3 mb-4">Why Aeps Service ?</h4>
                      <p className="text-muted para-desc mx-auto ms-lg-auto mb-0"> Aeps Service is a state-of-the-art B2C Digital Platform, under the parent SaaS based Company Aeps Service. registered under the Start-up India program.</p>
                      <div className="mt-4 d-lg-block d-none">
                        <a href="/login" className="btn btn-primary">See more</a>
                      </div>
                    </div>
                  </div>
                  <div className="col-lg-7 col-12 order-2 order-lg-1">
                    <div className="row me-lg-5">
                      <div className="col-md-6 col-12">
                        <div className="row">
                          <div className="col-12 mt-4 mt-lg-0 pt-2 pt-lg-0">
                            <div className="card border-0 text-center features feature-primary feature-clean course-feature p-4 overflow-hidden shadow">
                              <div className="icons text-center mx-auto">
                                <i className="uil uil-rocket d-block rounded-pill h3 mb-0" />
                              </div>
                              <div className="card-body p-0 mt-4">
                                <a href="javascript:void(0)" className="title h5 text-dark">One Wallet</a>
                                <p className="text-muted mt-2 mb-0">
                                  One wallet for all your services, no need to maintain funds in separate wallets, the same wallet acts as your settlement a/c as well</p>
                                <i className="uil uil-rocket full-img" />
                              </div>
                            </div>
                          </div>
                          <div className="col-12 mt-4 pt-2">
                            <div className="card border-0 text-center features feature-primary feature-clean course-feature p-4 overflow-hidden shadow">
                              <div className="icons text-center mx-auto">
                                <i className="uil uil-airplay d-block rounded-pill h3 mb-0" />
                              </div>
                              <div className="card-body p-0 mt-4">
                                <a href="javascript:void(0)" className="title h5 text-dark">Multiple Services</a>
                                <p className="text-muted mt-2 mb-0">
                                  Opportunity to increase your revenue multiple times as the portal is equipped with multiple services across different domains</p>
                                <i className="uil uil-airplay full-img" />
                              </div>
                            </div>
                          </div>
                        </div>
                      </div>
                      <div className="col-md-6 col-12">
                        <div className="row pt-lg-41 mt-lg-41">
                          <div className="col-12 mt-41 pt-12">
                            <div className="card border-0 text-center features feature-primary feature-clean course-feature p-4 overflow-hidden shadow">
                              <div className="icons text-center mx-auto">
                                <i className="uil uil-envelope d-block rounded-pill h3 mb-0" />
                              </div>
                              <div className="card-body p-0 mt-4">
                                <a href="javascript:void(0)" className="title h5 text-dark">Working Capital</a>
                                <p className="text-muted mt-2 mb-0">Our unique business model is plug and play experience where you can start your own business at minimal or Zero working capital.</p>
                                <i className="uil uil-envelope full-img" />
                              </div>
                            </div>
                          </div>
                          <div className="col-12 mt-4 pt-2">
                            <div className="card border-0 text-center features feature-primary feature-clean course-feature p-4 overflow-hidden shadow">
                              <div className="icons text-center mx-auto">
                                <i className="uil uil-bell d-block rounded-pill h3 mb-0" />
                              </div>
                              <div className="card-body p-0 mt-4">
                                <a href="javascript:void(0)" className="title h5 text-dark">Artificial Intelligence</a>
                                <p className="text-muted mt-2 mb-0">We have leveraged artificial intelligent so that the users get to enjoy lowest failures and fastest transactions in the industry.</p>
                                <i className="uil uil-bell full-img" />
                              </div>
                            </div>
                          </div>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
              <div className="container mt-100 mt-60" id="services">
                <div className="row justify-content-center">
                  <div className="col-12 text-center">
                    <div className="section-title mb-4 pb-2">
                      <h4 className="title mb-4"><span className="text-primary">One Wallet – </span>Multiple Services</h4>
                    </div>
                  </div>
                </div>
                <div className="row">
                  <div className="col-md-4 mt-4 pt-2">
                    <ul className="nav nav-pills nav-justified flex-column rounded shadow p-3 mb-0 sticky-bar" id="pills-tab" role="tablist">
                      <li className="nav-item" onClick={() => setActiveTab(1)}>
                        <a className={`nav-link rounded ${activeTab == 1 ? "active" : null}`} id="proposal" data-bs-toggle="pill" href="#developing" role="tab" aria-controls="developing" aria-selected="false">
                          <div className="text-start d-flex align-items-center justify-content-between py-1 px-2">
                            <h6 className="mb-0"><i className="uil uil-postcard me-2 h5" />Aadhaar Banking</h6>
                            <i className="uil uil-angle-right-b" />
                          </div>
                        </a>
                      </li>
                      <li className="nav-item mt-2" onClick={() => setActiveTab(2)}>
                        <a className={`nav-link rounded ${activeTab == 2 ? "active" : null}`} id="contract" data-bs-toggle="pill" href="#data-analise" role="tab" aria-controls="data-analise" aria-selected="false">
                          <div className="text-start d-flex align-items-center justify-content-between py-1 px-2">
                            <h6 className="mb-0"><i className="uil uil-notes me-2 h5" />Mini ATM</h6>
                            <i className="uil uil-angle-right-b" />
                          </div>
                        </a>
                      </li>
                      <li className="nav-item mt-2" onClick={() => setActiveTab("3")}>
                        <a className={`nav-link rounded ${activeTab == 3 ? "active" : null}`} id="crm" data-bs-toggle="pill" href="#security" role="tab" aria-controls="security" aria-selected="false">
                          <div className="text-start d-flex align-items-center justify-content-between py-1 px-2">
                            <h6 className="mb-0"><i className="uil uil-folder-check me-2 h5" />Money Transfer</h6>
                            <i className="uil uil-angle-right-b" />
                          </div>
                        </a>
                      </li>
                      <li className="nav-item mt-2" onClick={() => setActiveTab("4")}>
                        <a className={`nav-link rounded ${activeTab == 4 ? "active" : null}`} id="timetracking" data-bs-toggle="pill" href="#time-track" role="tab" aria-controls="time-track" aria-selected="false">
                          <div className="text-start d-flex align-items-center justify-content-between py-1 px-2">
                            <h6 className="mb-0"><i className="uil uil-clock me-2 h5" />Payment Solutions</h6>
                            <i className="uil uil-angle-right-b" />
                          </div>
                        </a>
                      </li>
                      <li className="nav-item mt-2" onClick={() => setActiveTab("5")}>
                        <a className={`nav-link rounded ${activeTab == 5 ? "active" : null}`} id="invoice" data-bs-toggle="pill" href="#invoices" role="tab" aria-controls="invoices" aria-selected="false">
                          <div className="text-start d-flex align-items-center justify-content-between py-1 px-2">
                            <h6 className="mb-0"><i className="uil uil-invoice me-2 h5" />Utility Services</h6>
                            <i className="uil uil-angle-right-b" />
                          </div>
                        </a>
                      </li>
                      <li className="nav-item mt-2" onClick={() => setActiveTab("6")}>
                        <a className={`nav-link rounded ${activeTab == 6 ? "active" : null}`} id="tasktracking" data-bs-toggle="pill" href="#task-track" role="tab" aria-controls="task-track" aria-selected="false">
                          <div className="text-start d-flex align-items-center justify-content-between py-1 px-2">
                            <h6 className="mb-0"><i className="uil uil-exchange-alt me-2 h5" />Savings Insurance Khata</h6>
                            <i className="uil uil-angle-right-b" />
                          </div>
                        </a>
                      </li>
                      <li className="nav-item mt-2" onClick={() => setActiveTab("7")}>
                        <a className={`nav-link rounded ${activeTab == 7 ? "active" : null}`} id="tasktracking" data-bs-toggle="pill" href="#task-track1" role="tab" aria-controls="task-track" aria-selected="false">
                          <div className="text-start d-flex align-items-center justify-content-between py-1 px-2">
                            <h6 className="mb-0"><i className="uil-card-atm me-2 h5" />Pre-Paid Card</h6>
                            <i className="uil uil-angle-right-b" />
                          </div>
                        </a>
                      </li>
                    </ul>
                  </div>
                  <div className="col-md-8 col-12 mt-4 pt-2">
                    <div className="tab-content" id="pills-tabContent">
                      <div className={`tab-pane fade  p-4 rounded shadow id="developing" role="tabpanel" aria-labelledby="proposal" ${activeTab == 1 ? "show active" : null}`}>
                        <h4 className="mb-4">Aadhaar Enabled Payment Services (AEPS)</h4>
                        <p className="text-muted mb-0">Any Aeps ServiceAEPS agent can convert their store into Aadhaar ATM. Customers can safely withdraw cash, get mini statement, balance inquiry and even payment can be done using their Aadhaar card and thumb authentication only! Aeps ServiceAEPS agent earns a high commission per transaction.</p>
                        <div className="mt-4">
                          <a href="#" className="text-primary h6">Know More<i className="uil uil-angle-right-b align-middle" /></a>
                        </div>
                        <div className="mt-4">
                          <img src="/assets/theme4/images/Aadhaar-Enabled-Payment-Services-(AEPS).webp" className="img-fluid" alt="Aadhaar Enabled Payment Services – AEPS" />
                        </div>
                      </div>
                      <div className={`tab-pane fade p-4 rounded shadow " id="data-analise" role="tabpanel" aria-labelledby="contract" ${activeTab == 2 ? "show active" : null}`}>
                        <h4 className="mb-4">Convert your Store into ATM</h4>
                        <p className="text-muted mb-0">Aeps Service Mini ATM machine is a solution for merchants who want to receive card payment anywhere, anytime, and who want to extend additional services to their customers. Convert your store into an ATM using the Micro ATM machine and provide cash withdrawal service at your outlet.</p>
                        <div className="mt-4">
                          <a href="#" className="text-primary h6">Know More<i className="uil uil-angle-right-b align-middle" /></a>
                        </div>
                        <div className="mt-4">
                          <img src="/assets/theme4/images/Mini-ATM-Machine.png" className="img-fluid" alt="Buy Mini Atm Machine - Aeps Service" />
                        </div>
                      </div>
                      <div className={`tab-pane fade p-4 rounded shadow" id="security" role="tabpanel" aria-labelledby="crm" ${activeTab == 3 ? "show active" : null}`}>
                        <h4 className="mb-4">Domestic Money Transfer (DMT)</h4>
                        <p className="text-muted mb-0">With Aeps Serviceyou have the opportunity to start money transfer business and transfer cash from your outlet to any Bank Account across the country with least charges in the industry, leading to a high income opportunity for all our money transfer agents. On every transaction, the retailer can earn a handsome income.</p>
                        <div className="mt-4">
                          <a href="#" className="text-primary h6">Know More<i className="uil uil-angle-right-b align-middle" /></a>
                        </div>
                        <div className="mt-4">
                          <img src="/assets/theme4/images/Money-Transfer.png" className="img-fluid" alt="Money Transfer Agent – Aeps Service" />
                        </div>
                      </div>
                      <div className={`tab-pane fade p-4 rounded shadow" id="time-track" role="tabpanel" aria-labelledby="timetracking" ${activeTab == 4 ? "show active" : null}`}>
                        <h4 className="mb-4">UPI, QR Code, MPOS, Aadhar Pay</h4>
                        <p className="text-muted mb-0">Aeps Servicepartners can offer multiple Payment options for the convenience of their customers- a unique UPI &amp; QR Code where customer can pay by scanning, MPOS for Debit/Credit Card Swipe, Payment Link for online payment and Aadhaar Pay where customers can pay using their Aadhaar card and many more.</p>
                        <div className="mt-4">
                          <a href="#" className="text-primary h6">Know More<i className="uil uil-angle-right-b align-middle" /></a>
                        </div>
                        <div className="mt-4">
                          <img src="/assets/theme4/images/Payment-Solutions.png" className="img-fluid" alt="Payment Solution – Aeps Service" />
                        </div>
                      </div>
                      <div className={`tab-pane fade p-4 rounded shadow" id="invoices" role="tabpanel" aria-labelledby="invoice" ${activeTab == 5 ? "show active" : null}`}>
                        <h4 className="mb-4">Recharge, Bill Payments, PAN Card</h4>
                        <p className="text-muted mb-0">Customer Mobile and DTH Recharge, Electricity, Gas and 30+ such bill payments, PAN Card Creation services are offered in Aeps Servicepanel to help the partner attract more customers and increase their service portfolio while earning money on each transaction.</p>
                        <div className="mt-4">
                          <a href="#" className="text-primary h6">Know More<i className="uil uil-angle-right-b align-middle" /></a>
                        </div>
                        <div className="mt-4">
                          <img src="/assets/theme4/images/Utility-Services.png" className="img-fluid" alt="Utility service – Aeps Service" />
                        </div>
                      </div>
                      <div className={`tab-pane fade p-4 rounded shadow" id="task-track" role="tabpanel" aria-labelledby="tasktracking" ${activeTab == 6 ? "show active" : null}`}>
                        <h4 className="mb-4">Risk Free Guaranteed Returns</h4>
                        <p className="text-muted mb-0">Ensuring Risk free guaranteed returns, Aeps Serviceintroduces an Insurance Saving plan with 25 times cover. Get more returns than any savings account on the amount invested. Aeps Servicepartners will add to their income and help customers fulfil their dreams with the savings plan.</p>
                        <div className="mt-4">
                          <a href="#" className="text-primary h6">Know More<i className="uil uil-angle-right-b align-middle" /></a>
                        </div>
                        <div className="mt-4">
                          <img src="/assets/theme4/images/Savings-Insurance-Khata.png" className="img-fluid" alt="Savings insurance khata – Aeps Service" />
                        </div>
                      </div>
                      <div className={`tab-pane fade bg-white p-4 rounded shadow" id="task-track1" role="tabpanel" aria-labelledby="prepaid" ${activeTab == 7 ? "show active" : null}`}>
                        <h4 className="mb-4">Debit Card without Account</h4>
                        <p className="text-muted mb-0">Using the Aeps ServicePrepaid card, Aeps Servicepartners can provide debit cards to customers who do not own a bank account. Customers can use these cards to pay for purchases like any normal debit card.</p>
                        <div className="mt-4">
                          <a href="#" className="text-primary h6">Know More<i className="uil uil-angle-right-b align-middle" /></a>
                        </div>
                        <div className="mt-4">
                          <img src="/assets/theme4/images/Pre-Paid-Cards.png" className="img-fluid" alt="Pre paid cards – Aeps Service" />
                        </div>
                      </div>
                    </div>{/*end tab content*/}
                  </div>
                </div>
              </div>
            </section>
            <div className="container mt-60" id="plan">
              <div className="row justify-content-center">
                <div className="col-12 text-center">
                  <div className="section-title mb-4 pb-2">
                    <h4 className="title mb-4"><span className="text-primary">Aeps Service</span> Services Plan</h4>
                    <p className="text-muted para-desc mb-0 mx-auto">Our unique platform has exciting <span className="text-primary fw-bold">business opportunity</span> for everyone, be it retailer, partner!</p>
                  </div>
                </div>
              </div>
              <div className="row justify-content-center">
                <div className="col-lg-8 col-md-12 mt-4 pt-2 text-center">
                  <ul className="nav nav-pills nav-justified flex-column flex-sm-row rounded" id="pills-tab" role="tablist">
                    <li className="nav-item" onClick={() => setActivePlan("1")}>
                      <a className={`nav-link rounded ${activePlan == 1 ? "active" : null}`} id="pills-cloud-tab" data-bs-toggle="pill" href="#pills-cloud" role="tab" aria-controls="pills-cloud" aria-selected="false">
                        <div className="text-center py-2">
                          <h6 className="mb-0">Sliver Plan</h6>
                        </div>
                      </a>
                    </li>
                    <li className="nav-item" onClick={() => setActivePlan("2")}>
                      <a className={`nav-link rounded ${activePlan == 2 ? "active" : null}`} id="pills-smart-tab" data-bs-toggle="pill" href="#pills-smart" role="tab" aria-controls="pills-smart" aria-selected="false">
                        <div className="text-center py-2">
                          <h6 className="mb-0">Gold Plan</h6>
                        </div>
                      </a>
                    </li>
                    <li className="nav-item" onClick={() => setActivePlan("3")}>
                      <a className={`nav-link rounded ${activePlan == 3 ? "active" : null}`} id="pills-apps-tab" data-bs-toggle="pill" href="#pills-apps" role="tab" aria-controls="pills-apps" aria-selected="false">
                        <div className="text-center py-2">
                          <h6 className="mb-0">Diamond Plan</h6>
                        </div>
                      </a>
                    </li>
                  </ul>
                </div>
              </div>
              <div className="row">
                <div className="col-12 mt-4 pt-2">
                  <div className="tab-content" id="pills-tabContent">
                    <div className={`tab-pane fade show" id="pills-cloud" role="tabpanel" aria-labelledby="pills-cloud-tab" ${activePlan == 1 ? "show active" : null}`}>
                      <div className="row align-items-center">
                        <div className="col-md-6">
                          <img src="/assets/theme4/images/planimages.webp" className="img-fluid mx-auto d-block" alt="Aeps ServiceRetailers" width={300} />
                        </div>
                        <div className="col-md-6 mt-4 mt-sm-0 pt-2 pt-sm-0">
                          <div className="section-title">
                            <h4 className="title mb-4"><i className="uil uil-angle-double-right text-primary" />Join Aeps Servicea Sliver Plan</h4>
                            <ul className="list-unstyled text-muted">
                              <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Normal Commission</li>
                              <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Email Support</li>
                              <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Normal Support</li>
                              <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Limited Features</li>
                              <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Single Pipeline</li>
                              <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>No Notification</li>
                              <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Normal Print</li>
                              <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Single Bank Payout Add</li>
                              <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>No Marketing Material</li>
                              <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Single device Access</li>
                              <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>No Certificate</li>
                            </ul>
                            <a href="#" target="_blank" className="mt-3 h6 btn-primary btn">Choose Plan<i className="uil uil-angle-right-b" /></a>
                          </div>
                        </div>
                      </div>
                    </div>
                    <div className={`tab-pane fade" id="pills-smart" role="tabpanel" aria-labelledby="pills-smart-tab" ${activePlan == 2 ? "show active" : null}`}>
                      <div className="row align-items-center">
                        <div className="col-md-6">
                          <img src="/assets/theme4/images/planimages.webp" className="img-fluid mx-auto d-block" alt="Aeps ServiceDistributors" width={300} />
                        </div>
                        <div className="col-md-6 mt-4 mt-sm-0 pt-2 pt-sm-0">
                          <div className="section-title">
                            <h4 className="title mb-4"><i className="uil uil-angle-double-right text-primary" />Join Aeps Servicea Gold Plan </h4>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>10% Extra Commission</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Email &amp; Call Support</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Dedicated Support</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Additional Features</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Double Pipeline</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Email Notification</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Normal &amp; thermal Print</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Double Bank Payout Add</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Digital Marketing Material</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Double device Access</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Digital Certificate</li>
                            <a href="#" className="mt-3 h6 btn-primary btn">Choose Plan<i className="uil uil-angle-right-b" /></a>
                          </div>
                        </div>
                      </div>
                    </div>
                    <div className={`tab-pane fade" id="pills-apps" role="tabpanel" aria-labelledby="pills-apps-tab" ${activePlan == 3 ? "show active" : null}`}>
                      <div className="row align-items-center">
                        <div className="col-md-6">
                          <img src="/assets/theme4/images/planimages.webp" className="img-fluid mx-auto d-block" alt="Aeps Service– Api White Lable Partners" width={300} />
                        </div>
                        <div className="col-md-6 mt-4 mt-sm-0 pt-2 pt-sm-0">
                          <div className="section-title">
                            <h4 className="title mb-4"><i className="uil uil-angle-double-right text-primary" />Join Aeps Servicea Diamond Plan </h4>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>30% Extra Commission</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Priority Relationship Manager</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Priority Support</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Full Features</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Multi Pipeline</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Email Notification</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Normal &amp; thermal Print</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Multi Bank Payout Add</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Physical Marketing Material</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Multi device Access</li>
                            <li className="mb-0"><span className="text-primary h5 me-2"><i className="uil uil-check-circle align-middle" /></span>Physical Certificate</li>
                            <a href="#" className="mt-3 h6 btn-primary btn">Choose Plan<i className="uil uil-angle-right-b" /></a>
                          </div>
                        </div>
                      </div>
                    </div>
                  </div>{/*end tab content*/}
                </div>
              </div>
            </div>
            <section className="section">
              <div className="container">
                <div className="row justify-content-center">
                  <div className="col-12 text-center">
                    <div className="section-title mb-4 pb-2">
                      <h4 className="title mb-4">The growth journey –<span className="text-primary fw-bold"> Aeps Service</span></h4>
                      <p className="text-muted para-desc mx-auto mb-0">Over the years <span className="text-primary fw-bold">Aeps Service</span> has spread its presence across the country and process 1 lac+ transactions daily.</p>
                    </div>
                  </div>
                </div>
                <div className="row" id="counter">
                  <div className="col-md-3 col-6 mt-4 pt-2">
                    <div className="counter-box text-center">
                      <img src="/assets/theme4/images/illustrator/Asset190.svg" className="avatar avatar-small" alt="100+ Districts – Aeps Service" />
                      <h2 className="mb-0 mt-4"><span className="counter-value" data-target={100}>3</span>+</h2>
                      <h6 className="counter-head text-muted">Districts Covered</h6>
                    </div>
                  </div>
                  <div className="col-md-3 col-6 mt-4 pt-2">
                    <div className="counter-box text-center">
                      <img src="/assets/theme4/images/illustrator/Asset189.svg" className="avatar avatar-small" alt="1 Lakh Retail Touch Points – Aeps Service" />
                      <h2 className="mb-0 mt-4"><span className="counter-value" data-target={10000}>0</span>+</h2>
                      <h6 className="counter-head text-muted">Retail Touch Points</h6>
                    </div>
                  </div>
                  <div className="col-md-3 col-6 mt-4 pt-2">
                    <div className="counter-box text-center">
                      <img src="/assets/theme4/images/illustrator/Asset192.svg" className="avatar avatar-small" alt="Daily Customer Transaction Volume – Aeps Service" />
                      <h2 className="mb-0 mt-4"><span className="counter-value" data-target={2}>0</span>Cr+</h2>
                      <h6 className="counter-head text-muted">Daily Transaction Volume</h6>
                    </div>
                  </div>
                  <div className="col-md-3 col-6 mt-4 pt-2">
                    <div className="counter-box text-center">
                      <img src="/assets/theme4/images/illustrator/Asset187.svg" className="avatar avatar-small" alt="Monthly Unique Customers – Aeps Service" />
                      <h2 className="mb-0 mt-4"><span className="counter-value" data-target={1}>0</span>Lacs+</h2>
                      <h6 className="counter-head text-muted">Monthly Unique Customers</h6>
                    </div>
                  </div>
                </div>
              </div>
              <div className="container mt-100 mt-60">
                <div className="row justify-content-center">
                  <div className="col-12 text-center">
                    <div className="section-title mb-4 pb-2">
                    </div>
                  </div>
                </div>
                <div className="row justify-content-center">
                  <div className="col-lg-12 mt-4">
                    <div className="tiny-two-item">
                      <div className="tiny-slide">
                        <div className="d-flex client-testi m-1">
                          <img src="/assets/theme4/images/test-3.jpeg" className="avatar avatar-small client-image rounded shadow" alt />
                          <div className="flex-1 content p-3 shadow rounded bg-white position-relative">
                            <ul className="list-unstyled mb-0">
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star-half text-warning" /></li>
                            </ul>
                            <p className="text-muted mt-2">" It has been quite a while since I have been retired, one of the greatest challenges that I faced was the minimalistic lifestyle I had to live to manage my finances and pay my bills, I was looking for a way to monetize from my free time. That’s when I got to know about Aeps Serviceit seemed like the best option for me. The guidance and training provided by the team were well structured and has helped me understand the business better and start making money sooner than what I had assumed. Now even though I am retired I don’t have to be reliant on anyone. "</p>
                            <h6 className="text-primary">- Mr Bhupati <small className="text-muted-testi">Retired Employee</small></h6>
                          </div>
                        </div>
                      </div>
                      <div className="tiny-slide">
                        <div className="d-flex client-testi m-1">
                          <img src="/assets/theme4/images/test-5.jpeg" className="avatar avatar-small client-image rounded shadow" alt />
                          <div className="flex-1 content p-3 shadow rounded bg-white position-relative">
                            <ul className="list-unstyled mb-0">
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                            </ul>
                            <p className="text-muted mt-2">" Housewives tends to face a lot of limitations especially when it comes to working out. After marriage, I wasn’t allowed to work. Although I didn’t want these limitations to stop me from moving ahead, Also, I thought I could help in supporting my family’s financial needs. After receiving advice from a well-wisher of mine I decided to opt for Aeps Service. It was the solution that well balanced my personal and professional life. Thank you Aeps Service!!! "</p>
                            <h6 className="text-primary">- Sangeeta <small className="text-muted-testi">Housewife</small></h6>
                          </div>
                        </div>
                      </div>
                      <div className="tiny-slide">
                        <div className="d-flex client-testi m-1">
                          <img src="/assets/theme4/images/test-2.jpeg" className="avatar avatar-small client-image rounded shadow" alt />
                          <div className="flex-1 content p-3 shadow rounded bg-white position-relative">
                            <ul className="list-unstyled mb-0">
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                            </ul>
                            <p className="text-muted mt-2">" Being an ambitious guy I always brainstorm with myself to get better ways to make more money, and I knew I had to start working at an early age but I also knew I had time to earn from a side gig. I wanted an option that would not affect my education. During my research, I came across the Aeps ServicePlatform which seemed promising to me and so I enrolled and got myself registered with them. Now I make enough to be able to finance my education. "</p>
                            <h6 className="text-primary">- Nikhil <small className="text-muted-testi">College student</small></h6>
                          </div>
                        </div>
                      </div>
                      <div className="tiny-slide">
                        <div className="d-flex client-testi m-1">
                          <img src="/assets/theme4/images/test-4.jpeg" className="avatar avatar-small client-image rounded shadow" alt />
                          <div className="flex-1 content p-3 shadow rounded bg-white position-relative">
                            <ul className="list-unstyled mb-0">
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                              <li className="list-inline-item"><i className="mdi mdi-star text-warning" /></li>
                            </ul>
                            <p className="text-muted mt-2">" Aeps Service given me the confidence to step up my game and start my own business all with minimal investment, I appreciate how they have streamlined their training process and how the whole team goes out of the way to support with any difficulties faced. The first thing that comes to a person’s mind before they start a business is where do I get my finances from? I don’t have expertise in anything, who will guide me in my venture? All these questions were answered well by Aeps Service.  "</p>
                            <h6 className="text-primary">- Rajesh <small className="text-muted-testi">Business owner</small></h6>
                          </div>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </section>
          </div>
        </form >
        {/* Footer Start */}
        < footer className="footer" id="contact" >
          <div className="container">
            <div className="row">
              <div className="col-lg-3 col-12 mb-0 mb-md-4 pb-0 pb-md-2">
                <a href="#" className="logo-footer">
                  <img src={apiResData?.logo} height="60px" alt />
                </a>
                <p className="mt-4 text-muted">{apiResData?.about}</p>
                <ul className="list-unstyled social-icon social mb-0 mt-4">
                  {/* <li className="list-inline-item"><a target="_blank" href="https://www.facebook.com/" className="rounded"><i data-feather="facebook" className="fe icon-sm fe-social" /></a></li>
                  <li className="list-inline-item"><a target="_blank" href="https://www.linkedin.com/" className="rounded"><i data-feather="linkedin" className="fea icon-sm fea-social" /></a></li>
                  <li className="list-inline-item"><a target="_blank" href="https://www.instagram.com/" className="rounded"><i data-feather="instagram" className="fea icon-sm fea-social" /></a></li>
                  <li className="list-inline-item"><a target="_blank" href="https://www.youtube.com/" className="rounded"><i data-feather="youtube" className="fea icon-sm fea-social" /></a></li> */}
                </ul>{/*end icon*/}
              </div>
              <div className="col-lg-2 col-md-2 col-12 mt-4 mt-sm-0 pt-2 pt-sm-0">
                <h5 className="footer-head">Our Services</h5>
                <ul className="list-unstyled footer-list mt-4">
                  <li><a href="#" className="sub-menu-item">AEPS</a></li>
                  <li><a href="#" className="sub-menu-item">Money Transfer</a></li>
                  <li><a href="#" className="sub-menu-item">Payment Solutions</a></li>
                  <li><a href="#" className="sub-menu-item">Pre-Paid cards</a></li>
                  <li><a href="#" className="sub-menu-item">Utility Services</a></li>
                  <li><a href="#" className="sub-menu-item">Insurance</a></li>
                  <li><a href="#" className="sub-menu-item">Bank Account</a></li>
                </ul>
              </div>
              <div className="col-lg-3 col-md-3 col-12 mt-4 mt-sm-0 pt-2 pt-sm-0">
                <h5 className="footer-head">Quick Links</h5>
                <ul className="list-unstyled footer-list mt-4">
                  <li><a href="#" className="text-muted"><i className="uil uil-angle-right-b me-1" />Home</a></li>
                  <li><a href="#about" className="text-muted"><i className="uil uil-angle-right-b me-1" /> About Us</a></li>
                  <li><a href="#plan" className="text-muted"><i className="uil uil-angle-right-b me-1" /> Pricing</a></li>
                  <li><a href="#" className="text-muted"><i className="uil uil-angle-right-b me-1" /> Privacy Policy</a></li>
                  <li><a href="#" className="text-muted"><i className="uil uil-angle-right-b me-1" /> Terms &amp; Conditions</a></li>
                  <li><a href="#contact" className="text-muted"><i className="uil uil-angle-right-b me-1" />  Contact Us</a></li>
                </ul>
              </div>
              <div className="col-lg-4 col-md-4 col-12 mt-4 mt-sm-0 pt-2 pt-sm-0">
                <h5 className="footer-head">Address</h5>

                <ul className="list-unstyled footer-list mt-4">
                  {/* <a href={`mailto:${apiResData?.company_email}`}> {apiResData?.company_email}</a> */}
                  <li><a href={`mailto:${apiResData?.company_email}`} className="text-muted"><i className="uil uil-angle-right-b me-1" />{apiResData?.company_email}</a></li>
                  <li><a href={`tel:${apiResData?.mobile_number}`} className="text-muted"><i className="uil uil-angle-right-b me-1" /> {apiResData?.mobile_number}</a></li>
                  <li><a href={`#`} className="text-muted"><i className="uil uil-angle-right-b me-1" /> {apiResData?.company_address}</a></li>
                </ul>
              </div>
            </div>
          </div>
        </footer >
        <footer className="footer footer-bar">
          <div className="container text-center">
            <div className="row align-items-center">
              <div className="col-sm-6">
                <div className="text-sm-start">
                  {
                    apiResData && apiResData?.design_developed_link ?

                      <p className="mb-0">© 2024 All Copyrights Reserved. | <a href={apiResData?.design_developed_link}>({apiResData?.design_developed})</a> </p>
                      : null
                  }

                </div>
              </div>
            </div>
          </div>
        </footer>
        <a href="#" onclick="topFunction()" id="back-to-top" className="back-to-top fs-5"><i data-feather="arrow-up" className="fea icon-sm icons align-middle" /></a>
      </div >

      <Script src="/assets/theme4/libs/bootstrap/js/bootstrap.bundle.min.js" strategy="afterInteractive" />
      <Script src="/assets/theme4/libs/feather-icons/feather.min.js" strategy="lazyOnload" />

      <Script src="/assets/theme4/libs/tiny-slider/min/tiny-slider.js" strategy="afterInteractive" />

      <Script src="/assets/theme4/js/app.js" strategy="lazyOnload" />
      <Script src="/assets/theme4/js/plugins.init.js" strategy="lazyOnload" />

    </>


  )
}

export default Home
